/*
 * Sistemas de Telecomunicações 
 *          2013/2014
 */
package calculator;

/**
 *
 * @author lflb@fct.unl.pt
 */
public class Calc_State {
    public final char IDLE_OPER= ' ';
    
    /**
     * Constructor - run when "new Calc_State()" is used
     */
    public Calc_State() {
        operand= 0;
        oper= IDLE_OPER;
    }
    
    /**
     * Returns the last operation
     * @return '+', '=' or IDLE_OPER
     */
    public char last_oper() {
        return oper;
    }
    
    /**
     * Returns the current operand
     * @return last_operand
     */
    public long operand() {
        return operand;
    }
    
    /**
     * Resets the state to the default values
     */
    public void reset() {
        operand= 0;
        oper= IDLE_OPER;
    }
    
    /**
     * Adds a new pair (operand, oper) to the state
     *     Example: "1+2=" is a sequence of (1,'+') and (2,'=')
     * @param new_operand
     * @param new_oper
     * @return true if success; false if error
     */  
    public boolean push_operation(long new_operand, char new_oper) {
        switch (oper) {
            case IDLE_OPER: // First operand
                operand= new_operand;
                break;
            case '+':   // Calculate pending addition
                operand += new_operand;
                break;
            case '=':
                break;
            default:    // Error - operation not supported
                reset();
                return false;
        }
        // Memorizes pending operation
        oper= new_oper;
        return true;
    }
            
    // Class local variables
    private long operand;
    private char oper;
}
